Package 'CortSineScore'

Title: What the Package Does (One Line, Title Case)
Description: What the package does (one paragraph).
Authors: First Last [aut, cre]
Maintainer: First Last <[email protected]>
License: Custom license (see LICENSE.txt)
Version: 0.0.0.9000
Built: 2026-05-12 23:32:54 UTC
Source: https://github.com/simone-anza/cortsinescore

Help Index


Compute Cortisol Sine Score (CSS)

Description

Compute Cortisol Sine Score (CSS)

Usage

compute_css(data)

Arguments

data

A data.frame in wide format, with the first column as subject ID, followed by cortisol values at time-specific columns (e.g., time_0200, time_0600, etc.)

Value

A data.frame with the original data and an added column cortisol_sin_score.

Examples

# Example usage:
# compute_css(your_dataframe)